@@ -33,7 +33,12 @@ import locale
 import stat
 import os
 
-ENCODING = locale.getpreferredencoding()
+
+def decode(s):
+    if isinstance(s, unicode):
+        return s
+    return unicode(s, "UTF-8", "replace")
+
 
 class DebPackageInfo(PackageInfo):
 
@@ -71,17 +76,18 @@ class DebPackageInfo(PackageInfo):
         if description:
             toks = description.split("\n", 1)
             if len(toks) == 2:
-                return toks[1]
-        return ""
+                return decode(toks[1])
+        return u""
 
     def getSummary(self):
         description = self._dict.get("description")
         if description:
-            return description.split("\n", 1)[0]
-        return ""
+            
+            return decode(description.split("\n", 1)[0])
+        return u""
 
     def getGroup(self):
-        return self._loader.getSection(self._package)
+        return decode(self._loader.getSection(self._package))
 
     def getPathList(self):
         self._paths = self._loader.getPaths(self)
@@ -95,6 +101,8 @@ class DebPackageInfo(PackageInfo):
 
 class DebTagLoader(Loader):
 
+    __stateversion__ = Loader.__stateversion__+1
+
     def __init__(self, baseurl=None):
         Loader.__init__(self)
         self._baseurl = baseurl
@@ -124,7 +132,12 @@ class DebTagLoader(Loader):
         Cnf = DebConflicts
         prog = iface.getProgress(self._cache)
         inst = self.getInstalled()
+        sysarch = DEBARCH
         for section, offset in self.getSections(prog):
+            arch = section.get("architecture")
+            if arch and arch != sysarch and arch != "all":
+                continue
+
             if inst:
                 try:
                     want, flag, status = section.get("status", "").split()
@@ -379,7 +392,11 @@ def getControl(filename):
         if name == "control.tar.gz  ":
             data = file.read(int(size))
             sio = StringIO(data)
-            control = TarFile.gzopen("", fileobj=sio).extractfile("control")
+            tf = TarFile.gzopen("", fileobj=sio)
+            try:
+                control = tf.extractfile("./control")
+            except KeyError:
+                control = tf.extractfile("control")
             return control.read()
         else:
             file.seek(int(size), 1)
