@@ -19,18 +19,28 @@
 # along with Smart Package Manager; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+import threading
+import tempfile
+import sys, os
+import signal
+import errno
+import shlex
+
 from smart.const import INSTALL, REMOVE, OPTIONAL, ENFORCE
 from smart.pm import PackageManager
 from smart.sorter import *
 from smart import *
-import sys, os
-import signal
+
 
 # Part of the logic in this file was based on information found in APT.
 
 UNPACK = 10
 CONFIG = 11
 
+DEBIAN_FRONTEND = "DEBIAN_FRONTEND"
+APT_LISTCHANGES_FRONTEND = "APT_LISTCHANGES_FRONTEND"
+
+
 class DebSorter(ElementSorter):
 
     def __init__(self, changeset=None):
@@ -113,6 +123,7 @@ class DebSorter(ElementSorter):
                     if changeset.get(cnfpkg) is REMOVE:
                         self.addSuccessor((cnfpkg, REMOVE), unpack, ENFORCE)
 
+
 class DebPackageManager(PackageManager):
 
     MAXPKGSPEROP = 50
@@ -123,7 +134,6 @@ class DebPackageManager(PackageManager):
         prog.start()
         prog.setTopic(_("Committing transaction..."))
         prog.show()
-        print
 
         # Compute upgraded packages
         upgraded = {}
@@ -164,7 +174,7 @@ class DebPackageManager(PackageManager):
 
         prog.set(0, len(sorted))
 
-        baseargs = [sysconf.get("dpkg", "dpkg")]
+        baseargs = shlex.split(sysconf.get("dpkg", "dpkg"))
 
         opt = sysconf.get("deb-root")
         if opt:
@@ -184,7 +194,21 @@ class DebPackageManager(PackageManager):
                 if op is REMOVE and not upgraded.get(pkg):
                     sorted[i] = pkg, PURGE
 
+        if sysconf.get("deb-non-interactive"):
+            old_debian_frontend = os.environ.get(DEBIAN_FRONTEND)
+            old_apt_lc_frontend = os.environ.get(APT_LISTCHANGES_FRONTEND)
+            os.environ[DEBIAN_FRONTEND] = "noninteractive"
+            os.environ[APT_LISTCHANGES_FRONTEND] = "none"
+
+        if sysconf.get("pm-iface-output"):
+            output = tempfile.TemporaryFile()
+        else:
+            output = sys.stdout
+
+        print >>output
+
         done = {}
+        error = None
         while sorted:
 
             pkgs = []
@@ -197,7 +221,7 @@ class DebPackageManager(PackageManager):
                 done[pkg] = True
                 opname = {REMOVE: "remove", PURGE: "purge", CONFIG: "config",
                           UNPACK: "unpack", INSTALL: "install"}
-                print "[%s] %s" % (opname[op], pkg)
+                print >>output, "[%s] %s" % (opname[op], pkg)
                 pkgs.append(pkg)
 
             if not pkgs:
@@ -226,44 +250,84 @@ class DebPackageManager(PackageManager):
                 for pkg in pkgs:
                     args.append(pkg.name)
 
-            quithandler = signal.signal(signal.SIGQUIT, signal.SIG_IGN)
-            inthandler  = signal.signal(signal.SIGINT, signal.SIG_IGN)
+            thread_name = threading.currentThread().getName()
+            if thread_name == "MainThread":
+                quithandler = signal.signal(signal.SIGQUIT, signal.SIG_IGN)
+                inthandler  = signal.signal(signal.SIGINT, signal.SIG_IGN)
 
-            print " ".join(args)
-            pid = os.fork()
-            if not pid:
-                os.execvp(args[0], args)
-                os._exit(1)
+            output.flush()
 
-            while True:
-                _pid, status = os.waitpid(pid, 0)
-                if _pid == pid:
-                    break
+            status = self.dpkg(args, output)
 
-            signal.signal(signal.SIGQUIT, quithandler)
-            signal.signal(signal.SIGINT,  inthandler)
+            if thread_name == "MainThread":
+                signal.signal(signal.SIGQUIT, quithandler)
+                signal.signal(signal.SIGINT,  inthandler)
 
             if not os.WIFEXITED(status) or os.WEXITSTATUS(status) != 0:
-
                 if os.WIFSIGNALED(status) and os.WTERMSIG(status):
-                    iface.error(_("Sub-process %s has received a "
-                                  "segmentation fault") % args[0])
+                    error = _("Sub-process %s has received a "
+                              "segmentation fault") % args[0]
                 elif os.WIFEXITED(status):
-                    iface.error(_("Sub-process %s returned an error code "
-                                  "(%d)") % (args[0], os.WEXITSTATUS(status)))
+                    error = _("Sub-process %s returned an error code "
+                              "(%d)") % (args[0], os.WEXITSTATUS(status))
                 else:
-                    iface.error(_("Sub-process %s exited unexpectedly")
-                                % args[0])
-                prog.setDone()
-                prog.stop()
-                return
+                    error = _("Sub-process %s exited unexpectedly") % args[0]
+                break
 
-            print
+            print >>output # Should avoid that somehow.
             prog.add(len(pkgs))
             prog.show()
-            print
+            print >>output # Should avoid that somehow.
+
+        if output != sys.stdout:
+            output.flush()
+            output.seek(0)
+            data = output.read(8192)
+            while data:
+                iface.showOutput(data)
+                data = output.read(8192)
+            output.close()
+
+        if sysconf.get("deb-non-interactive"):
+            if old_debian_frontend is None:
+                del os.environ[DEBIAN_FRONTEND]
+            else:
+                os.environ[DEBIAN_FRONTEND] = old_debian_frontend
+            if old_apt_lc_frontend is None:
+                del os.environ[APT_LISTCHANGES_FRONTEND]
+            else:
+                os.environ[APT_LISTCHANGES_FRONTEND] = old_apt_lc_frontend
+
+        if error:
+            iface.error(error)
 
         prog.setDone()
         prog.stop()
 
+    def dpkg(self, argv, output):
+        pid = os.fork()
+        if not pid:
+            if output != sys.stdout:
+                output_fd = output.fileno()
+                os.dup2(output_fd, 1)
+                os.dup2(output_fd, 2)
+            #print >>output, " ".join(argv)
+            os.execvp(argv[0], argv)
+            os._exit(1)
+
+        output.flush()
+
+        while True:
+            try:
+                _pid, status = os.waitpid(pid, 0)
+            except OSError, e:
+                if e.errno != errno.EINTR:
+                    raise
+            else:
+                if _pid == pid:
+                    break
+
+        return status
+
+
 # vim:ts=4:sw=4:et
