@@ -22,7 +22,15 @@
 #
 from smart.cache import PackageInfo, Loader
 from smart.backends.rpm.base import *
-from smart.util import cElementTree
+
+try:
+    from xml.etree import cElementTree        
+except ImportError:
+    try:
+        import cElementTree
+    except ImportError:     
+        from smart.util import cElementTree
+
 from smart import *
 import posixpath
 import locale
@@ -266,8 +274,9 @@ class RPMMetaDataLoader(Loader):
                              name, '<', versionarch)] = True
 
                     reqargs = [x for x in reqdict
-                               if x[2] not in ("=",">=","<=") or
-                                  (RPMProvides, x[1], x[3]) not in prvdict]
+                               if not ((x[2] is None or "=" in x[2]) and
+                                       (RPMProvides, x[1], x[3]) in prvdict or
+                                       system_provides.match(*x[:3]))]
                     prvargs = prvdict.keys()
                     cnfargs = cnfdict.keys()
                     upgargs = upgdict.keys()
