@@ -28,6 +28,7 @@ from smart.searcher import Searcher
 from smart.media import MediaSet
 from smart.progress import Progress
 from smart.fetcher import Fetcher
+from smart.report import Report
 from smart.channel import *
 from smart.cache import *
 from smart.const import *
@@ -300,6 +301,8 @@ class Control(object):
                 raise Error, _("Unable to create channel directory.")
         if caching is ALWAYS:
             if sysconf.getReadOnly() and os.access(channelsdir, os.W_OK):
+                iface.warning(_("The Smart library is already in use by "
+                                "another process."))
                 iface.warning(_("Configuration is in readonly mode!"))
             if not self._pathlocks.lock(channelsdir):
                 raise Error, _("Channel information is locked for writing.")
@@ -414,30 +417,22 @@ class Control(object):
         for url in urls:
             print >>output, url
 
-    def dumpTransactionPackages(self, trans, action="install", noversion=False, file=""):
-        print
-        from smart.report import Report
-        report = Report(trans.getChangeSet())
-        report.compute()
-        if action == "install":
-            pkgs = report.installing
-        elif action == "upgrade":
-            pkgs = report.upgrading
-        elif action == "remove":
-            pkgs = report.removed
-        items = pkgs.items()
-        items.sort()
-        pkgs = [key for key, value in items]
-        if file:
-            output = open(file, 'w')
-        else:
+    def dumpTransactionPackages(self, trans, install=False, remove=False,
+                                output=None):
+        if output is None:
             output = sys.stderr
+        ops = set()
+        if install:
+            ops.add(INSTALL)
+        if remove:
+            ops.add(REMOVE)
+        pkgs = [pkg for (pkg, op) in trans.getChangeSet().items() if op in ops]
+        pkgs.sort()
         for pkg in pkgs:
-            if noversion:
-                print >>output, pkg.name
+            if sysconf.get("dump-versions", True):
+                print >> output, pkg
             else:
-                print >>output, pkg
-        if file:output.close()
+                print >> output, pkg.name
 
     def downloadURLs(self, urllst, what=None, caching=NEVER, targetdir=None):
         fetcher = self._fetcher
@@ -507,7 +502,7 @@ class Control(object):
     def commitChangeSet(self, changeset, caching=OPTIONAL, confirm=True):
         if confirm and not iface.confirmChangeSet(changeset):
             return False
-            
+
         if not confirm:
             iface.showChangeSet(changeset)
 
