@@ -538,7 +538,7 @@ class FetchItem(object):
 
     def updateETA(self):
         if self._status is RUNNING:
-            if (self._speed > 0) and (self._total > 0):
+            if (self._speed > 1) and (self._total > 0):
                 self._eta = (self._total - self._current) / self._speed
             else:
                 self._eta = None
@@ -1117,7 +1117,7 @@ class URLLIBHandler(FetcherHandler):
                 if self.retrycount <= 0:
                     return self.http_error_default(url, fp, errcode, errmsg, headers)
                 return urllib.FancyURLopener.http_error_401(self, url, fp, errcode, errmsg, headers, data)
-            def get_user_passwd(self, host, realm):
+            def get_user_passwd(self, host, realm, clear_cache = 0):
                 return self.user, self.passwd
             def http_error_default(self, url, fp, errcode, errmsg, headers):
                 if not fp:
