@@ -61,14 +61,15 @@ class GtkChannels(object):
         self._treemodel = gtk.ListStore(gobject.TYPE_INT,
                                         gobject.TYPE_STRING,
                                         gobject.TYPE_STRING,
-                                        gobject.TYPE_STRING)
+                                        gobject.TYPE_STRING,
+                                        gobject.TYPE_INT);
         self._treeview = gtk.TreeView(self._treemodel)
         self._treeview.set_rules_hint(True)
         self._treeview.show()
         sw.add(self._treeview)
 
         renderer = gtk.CellRendererToggle()
-        renderer.set_property("xpad", 3)
+        renderer.set_property("xpad", 4)
         renderer.set_active(False)
         def toggled(cell, path):
             model = self._treemodel
@@ -79,7 +80,9 @@ class GtkChannels(object):
                                                      active=0)
 
         renderer = gtk.CellRendererText()
-        renderer.set_property("xpad", 3)
+        renderer.set_property("xpad", 4)
+        self._treeview.insert_column_with_attributes(-1, _("Pri"), renderer,
+                                                     text=4)
         self._treeview.insert_column_with_attributes(-1, _("Alias"), renderer,
                                                      text=1)
         self._treeview.insert_column_with_attributes(-1, _("Type"), renderer,
@@ -137,7 +140,9 @@ class GtkChannels(object):
             self._treemodel.append((not strToBool(channel.get("disabled")),
                                     alias,
                                     channel.get("type", ""),
-                                    channel.get("name", "")))
+                                    channel.get("name", ""),
+                                    int(channel.get("priority", "") or 0),
+))
 
     def enableDisable(self):
         for row in self._treemodel:
@@ -190,12 +195,15 @@ class GtkChannels(object):
         elif method in ("descriptionpath", "descriptionurl"):
 
             if method == "descriptionpath":
-                #dia = gtk.FileChooserDialog(
-                #             action=gtk.FILE_CHOOSER_ACTION_OPEN,
-                #             buttons=(gtk.STOCK_OK, gtk.RESPONSE_OK,
-                #                      gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT))
-                dia = gtk.FileSelection(_("Select Channel Description"))
-                dia.hide_fileop_buttons()
+                if gtk.pygtk_version > (2,4,0):
+                    dia = gtk.FileChooserDialog(
+                        action=gtk.FILE_CHOOSER_ACTION_OPEN,
+                        buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
+                                 gtk.STOCK_OK, gtk.RESPONSE_OK))
+                                 
+                else:
+                    dia = gtk.FileSelection(_("Select Channel Description"))
+                    dia.hide_fileop_buttons()
                 response = dia.run()
                 filename = dia.get_filename()
                 dia.destroy()
@@ -242,8 +250,15 @@ class GtkChannels(object):
                 if not path:
                     return
             elif method == "detectpath":
-                dia = gtk.FileSelection(_("Select Path"))
-                dia.hide_fileop_buttons()
+                if gtk.pygtk_version > (2,4,0):
+                    dia = gtk.FileChooserDialog(
+                        action=gtk.FILE_CHOOSER_ACTION_OPEN,
+                        buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
+                                 gtk.STOCK_OK, gtk.RESPONSE_OK))
+                                 
+                else:
+                    dia = gtk.FileSelection(_("Select Path"))
+                    dia.hide_fileop_buttons()
                 response = dia.run()
                 path = dia.get_filename()
                 dia.destroy()
@@ -362,6 +377,11 @@ class GtkChannelSelector(object):
         bbox.show()
         vbox.pack_start(bbox, expand=False)
 
+        button = gtk.Button(stock="gtk-cancel")
+        button.show()
+        button.connect("clicked", lambda x: gtk.main_quit())
+        bbox.pack_start(button)
+
         button = gtk.Button(stock="gtk-ok")
         button.show()
         def clicked(x):
@@ -370,10 +390,6 @@ class GtkChannelSelector(object):
         button.connect("clicked", clicked)
         bbox.pack_start(button)
 
-        button = gtk.Button(stock="gtk-cancel")
-        button.show()
-        button.connect("clicked", lambda x: gtk.main_quit())
-        bbox.pack_start(button)
 
     def fill(self):
         self._treemodel.clear()
@@ -444,6 +460,11 @@ class ChannelEditor(object):
         bbox.show()
         vbox.pack_start(bbox, expand=False)
 
+        button = gtk.Button(stock="gtk-cancel")
+        button.show()
+        button.connect("clicked", lambda x: gtk.main_quit())
+        bbox.pack_start(button)
+
         button = gtk.Button(stock="gtk-ok")
         button.show()
         def clicked(x):
@@ -452,10 +473,6 @@ class ChannelEditor(object):
         button.connect("clicked", clicked)
         bbox.pack_start(button)
 
-        button = gtk.Button(stock="gtk-cancel")
-        button.show()
-        button.connect("clicked", lambda x: gtk.main_quit())
-        bbox.pack_start(button)
 
     def addField(self, key, label, value, ftype,
                  editable=True, tip=None, needed=False):
@@ -512,7 +529,9 @@ class ChannelEditor(object):
         self._fieldn += 1
 
     def show(self, alias, oldchannel, editalias=False):
+        # reset the dialog fields
         self._table.foreach(self._table.remove)
+        self._fieldn = 0
 
         if len(oldchannel) > 1:
             # This won't be needed once old format channels
@@ -626,6 +645,11 @@ class TypeSelector(object):
         bbox.show()
         vbox.pack_start(bbox, expand=False)
 
+        button = gtk.Button(stock="gtk-cancel")
+        button.show()
+        button.connect("clicked", lambda x: gtk.main_quit())
+        bbox.pack_start(button)
+
         self._ok = button = gtk.Button(stock="gtk-ok")
         button.show()
         def clicked(x):
@@ -634,10 +658,6 @@ class TypeSelector(object):
         button.connect("clicked", clicked)
         bbox.pack_start(button)
 
-        button = gtk.Button(stock="gtk-cancel")
-        button.show()
-        button.connect("clicked", lambda x: gtk.main_quit())
-        bbox.pack_start(button)
 
     def show(self):
         self._typevbox.foreach(self._typevbox.remove)
@@ -721,6 +741,11 @@ class MethodSelector(object):
         bbox.show()
         vbox.pack_start(bbox, expand=False)
 
+        button = gtk.Button(stock="gtk-cancel")
+        button.show()
+        button.connect("clicked", lambda x: gtk.main_quit())
+        bbox.pack_start(button)
+
         ok = button = gtk.Button(stock="gtk-ok")
         button.show()
         def clicked(x):
@@ -729,11 +754,6 @@ class MethodSelector(object):
         button.connect("clicked", clicked)
         bbox.pack_start(button)
 
-        button = gtk.Button(stock="gtk-cancel")
-        button.show()
-        button.connect("clicked", lambda x: gtk.main_quit())
-        bbox.pack_start(button)
-
         radio = None
         self._method = None
         def method_toggled(button, method):
