@@ -63,10 +63,10 @@ class GtkProgress(Progress, gtk.Window):
         self._topic.show()
         vbox.pack_start(self._topic, expand=False, fill=False)
 
-        self._progress = gtk.ProgressBar()
-        self._progress.set_size_request(-1, 25)
-        self._progress.show()
-        vbox.pack_start(self._progress, expand=False, fill=False)
+        self._progressbar = gtk.ProgressBar()
+        self._progressbar.set_size_request(-1, 25)
+        self._progressbar.show()
+        vbox.pack_start(self._progressbar, expand=False, fill=False)
 
         if hassub:
             self._scrollwin = gtk.ScrolledWindow()
@@ -80,6 +80,7 @@ class GtkProgress(Progress, gtk.Window):
                                             gobject.TYPE_STRING,
                                             gobject.TYPE_STRING,
                                             gobject.TYPE_STRING,
+                                            gobject.TYPE_STRING,
                                             gobject.TYPE_STRING)
             self._treeview = gtk.TreeView(self._treemodel)
             self._treeview.show()
@@ -109,6 +110,12 @@ class GtkProgress(Progress, gtk.Window):
             self._speedcolumn = column
             self._treeview.append_column(column)
 
+            renderer = gtk.CellRendererText()
+            renderer.set_fixed_height_from_font(True)
+            column = gtk.TreeViewColumn(_("ETA"), renderer, text=5)
+            self._etacolumn = column
+            self._treeview.append_column(column)
+
             renderer = gtk.CellRendererText()
             renderer.set_fixed_height_from_font(True)
             column = gtk.TreeViewColumn(_("Description"), renderer, text=1)
@@ -160,6 +167,7 @@ class GtkProgress(Progress, gtk.Window):
             self._currentcolumn.set_visible(False)
             self._totalcolumn.set_visible(False)
             self._speedcolumn.set_visible(False)
+            self._etacolumn.set_visible(False)
 
         thread.start_new_thread(self.tick, ())
 
@@ -208,17 +216,24 @@ class GtkProgress(Progress, gtk.Window):
             total = data.get("total", "")
             if total:
                 self._totalcolumn.set_visible(True)
-            speed = data.get("speed", "")
-            if speed:
-                self._speedcolumn.set_visible(True)
-            if current or total or speed:
-                self._treemodel.set(iter, 2, current, 3, total, 4, speed)
+            if done:
+                speed = "Done"
+                eta = "Done"
+            else:
+                speed = data.get("speed", "")
+                if speed:
+                    self._speedcolumn.set_visible(True)
+                eta = data.get("eta", "")
+                if eta:
+                    self._etacolumn.set_visible(True)
+            if current or total or speed or eta:
+                self._treemodel.set(iter, 2, current, 3, total, 4, speed, 5, eta)
                 subtopic = self._shorturl.get(subtopic)
             self._treemodel.set(iter, 0, subpercent, 1, subtopic)
         else:
             self._topic.set_text(topic)
-            self._progress.set_fraction(percent/100.)
-            self._progress.set_text("%d%%" % percent)
+            self._progressbar.set_fraction(percent/100.)
+            self._progressbar.set_text("%d%%" % percent)
             if self._hassub:
                 self._treeview.queue_draw()
 
